==> prestashop_1.4.0.7.zip: prestashop/modules/twenga/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{twenga}prestashop>TwengaObj_2823b98d043387f608f16d5830d63f5f'] = 'Pour activer le module Twenga, la constante \"PARTNER_AUTH_KEY\" doit être définit. L\'installation par défault de Prestashop contient cette valeur.';
$_MODULE['<{twenga}prestashop>TwengaObj_9f7cd403f4ab77ce8c00426d4a01345e'] = 'L\'object pour valider les champs doit être une instance de la classe TwengaFields';
$_MODULE['<{twenga}prestashop>TwengaObj_b78d4ca3fa82bab9e21c8110511ed947'] = 'Le retour XML de la réponse HTTP n\'est pas analysable :';
$_MODULE['<{twenga}prestashop>TwengaObj_7edc522b57a063ef075b68fdb791af40'] = 'la réponse HTTP est vide';
$_MODULE['<{twenga}prestashop>TwengaObj_d00d3f61833c8686be3f0ca7df670e20'] = 'Cet appel aux Services Web Twenga à échoué et à retourné un statut HTTP de %d. Ce qui veut dire :';
$_MODULE['<{twenga}prestashop>TwengaObj_5177c3a8e526ccb227441827d43d9583'] = 'La fonction que vous appelez n\'existe pas';
$_MODULE['<{twenga}prestashop>TwengaObj_3718cdfdc7439f35aed9f053b5991baf'] = 'Un champ requis est vide.';
$_MODULE['<{twenga}prestashop>TwengaObj_f97fd38d65fe891d07fc1a157b0752a2'] = 'Le type du paramètre qui est envoyé est différent du type attendu.';
$_MODULE['<{twenga}prestashop>TwengaObj_737b702af5cbf3c4b0e7404592bae85e'] = 'Le hash key n\'est pas valide';
$_MODULE['<{twenga}prestashop>TwengaObj_c54550e963195bd4e80b862f40b8d574'] = 'Le hash key est requis';
$_MODULE['<{twenga}prestashop>TwengaObj_c4e170c475b0285f284ccb066bcd81f4'] = 'Aucune commandes trouvées. Regardez les parmètres que vous transmettez';
$_MODULE['<{twenga}prestashop>TwengaObj_54441256ce04ab07a29463646d0a9931'] = 'Une authentification est requise.';
$_MODULE['<{twenga}prestashop>TwengaObj_802b207b05fe5cea22e11b9db804b33d'] = 'L\'authentification a échoué.';
$_MODULE['<{twenga}prestashop>TwengaObj_629a8cfa226f98886062bfdc9666e266'] = 'L\'url n\'est pas valide.';
$_MODULE['<{twenga}prestashop>TwengaObj_9fb66ea632c1aff220b180918df3c77c'] = 'Le serveur à rencontrer une \"internal server error\".';
$_MODULE['<{twenga}prestashop>TwengaObj_6e182f2ba494a6720ce552ed2a255403'] = 'Le serveur n\'est pas accessible pour le moment';
$_MODULE['<{twenga}prestashop>TwengaObj_4252fb7eb531ed1ec250e5c16f8ced37'] = 'Cet appel aux Services Web Twenga a retourné un statut HTTP inattendu :';
$_MODULE['<{twenga}prestashop>TwengaObj_5619f08f21127bd8f72ec9bbb25031ac'] = 'Erreur n°';
$_MODULE['<{twenga}prestashop>twenga_400b0c914f01bcecf50b936e652695b2'] = 'l\'API de Twenga';
$_MODULE['<{twenga}prestashop>twenga_aa2bebad4fe3e659723e56cc7fcc6b1c'] = 'Exportez vos produits sur twenga.com et utilisez le tracker de Twenga pour les commandes de vos consommateurs.';
$_MODULE['<{twenga}prestashop>twenga_69e591b18e717d483dbaa8e3ce89ce59'] = 'Les paramètres ne sont pas autorisés (voir détails) :';
$_MODULE['<{twenga}prestashop>twenga_75a462904fadc0cc16d084efaef4a9d0'] = 'Une erreur s\'est produite avec une méthode de l\'API Twenga (voir détails) :';
$_MODULE['<{twenga}prestashop>twenga_cecc441ee7cb4cbbf1953d44018706de'] = 'Votre \"hashkey\" n\'est pas valide. Veuillez vérifier l\'email envoyé par Twenga.';
$_MODULE['<{twenga}prestashop>twenga_0483e8a340c21e92e606aa0cd2bafbe7'] = 'Votre nom d\'utilisateur n\'est pas valide. Veuillez vérifier l\'email envoyé par Twenga.';
$_MODULE['<{twenga}prestashop>twenga_54d92b2c87281ba0247f14a8eaea3278'] = 'Votre mot de passe n\'est pas valide. Veuillez vérifier l\'email envoyé par Twenga.';
$_MODULE['<{twenga}prestashop>twenga_b0d43a97cdf2e31e3d6b26640c2e71ee'] = 'Votre authentification à échoué.';
$_MODULE['<{twenga}prestashop>twenga_638a1f975b1d8361fcd459c532db6634'] = 'Veuillez vérifier l\'email envoyé par Twenga après souscription. Si une erreur persiste, contactez le service de Twenga.';
$_MODULE['<{twenga}prestashop>twenga_ddedf0f7b923553ef46616375e521381'] = 'Une erreur est apparue en passant les paramètres à l\'API Twenga.';
$_MODULE['<{twenga}prestashop>twenga_378f76d06c0d43d9fe5b5ab561e06d09'] = 'Pour utiliser le webservice de Twenga, vous devez activer l\'extension \'curl\' de PHP';
$_MODULE['<{twenga}prestashop>twenga_0c619ac2ab02e76d399db8e053344f9d'] = 'Twenga';
$_MODULE['<{twenga}prestashop>twenga_0e78527dac17a461f84dceee220109cf'] = 'Après avoir souscrit à l\'API de Twenga, Twenga vous envoie votre \"hashkey\", un login, et mot de passe pour utiliser l\'API.';
$_MODULE['<{twenga}prestashop>twenga_a66daa775d445ee7da1bb20667b7c8e6'] = 'Flux Rss';
$_MODULE['<{twenga}prestashop>twenga_21baf392bfae2dadba6813e9fb843141'] = 'Hashkey';
$_MODULE['<{twenga}prestashop>twenga_99dea78007133396a7b8ed70578ac6ae'] = 'Login';
$_MODULE['<{twenga}prestashop>twenga_dc647eb65e6711e155375218212b3964'] = 'Mot de passe';
$_MODULE['<{twenga}prestashop>twenga_43781db5c40ecc39fd718685594f0956'] = 'Sauvegarder';
$_MODULE['<{twenga}prestashop>twenga_787ad0b7a17de4ad6b1711bbf8d79fcb'] = 'Souscription';
$_MODULE['<{twenga}prestashop>twenga_113560aefce6245acec25d96748d1bf7'] = 'Pour préparer votre souscription à l\'API de Twenga,';
$_MODULE['<{twenga}prestashop>twenga_6c70656b03e4bd8e59be0090a0277bac'] = 'Veuillez vérifier le formulaire ci-dessous et cliquez sur \"sauvegarder\" pour accéder au formulaire de souscription de Twenga';
$_MODULE['<{twenga}prestashop>twenga_87fa3060dcb794dee724d4cb59b13cd6'] = 'l\'url du site';
$_MODULE['<{twenga}prestashop>twenga_1ce44171ccfff23c4fc2c836ad6543f4'] = 'Flux Rss, la liste des produits en xml.';
$_MODULE['<{twenga}prestashop>twenga_670e0c29cdde1886890aebc751cd6e89'] = 'Valeur automatiquement remplie, ne la changer pas.';
$_MODULE['<{twenga}prestashop>twenga_59716c97497eb9694541f7c3d37b1a4d'] = 'Pays';
$_MODULE['<{twenga}prestashop>twenga_95f01a5bae7b4b64a76372538e4fd315'] = 'Le pays de la société E-commerce. Utilisez le code ISO_3166-1 Alpha-2 pour le format de pays ';
$_MODULE['<{twenga}prestashop>twenga_734b599bad38d4210614bc176c53fefe'] = 'Nom du site';
$_MODULE['<{twenga}prestashop>twenga_dff4bf10409100d989495c6d5486035e'] = 'Nom de famille';
$_MODULE['<{twenga}prestashop>twenga_04176f095283bc729f1e3926967e7034'] = 'Prénom';
$_MODULE['<{twenga}prestashop>twenga_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'E-mail';
$_MODULE['<{twenga}prestashop>twenga_bcc254b55c4a1babdf1dcb82c207506b'] = 'Téléphone';
$_MODULE['<{twenga}prestashop>twenga_28bea34e08fa23a7d394c93bad717733'] = 'Nom de l\'organisation';
$_MODULE['<{twenga}prestashop>twenga_4ff5049a0938728934387c4d9cf38f94'] = 'Infos juridiques';
$_MODULE['<{twenga}prestashop>twenga_dfd7564600980a3470f2ec24766653fe'] = 'Infos juridiques de la société.';
$_MODULE['<{twenga}prestashop>twenga_dd7bf230fde8d4836917806aff6a6b27'] = 'Adresse';
$_MODULE['<{twenga}prestashop>twenga_572ed696f21038e6cc6c86bb272a3222'] = 'Code postale';
$_MODULE['<{twenga}prestashop>twenga_57d056ed0984166336b7879c2af3657f'] = 'Ville';
$_MODULE['<{twenga}prestashop>twenga_c9cc8cce247e49bae79f15173ce97354'] = 'Sauvegarder';
$_MODULE['<{twenga}prestashop>twenga_435ad0ad5987e5c3b1304cf00472216d'] = 'Si vous n\'êtes pas redirigé sur le formulaire d\'inscription de L\'API de Twenga, cliquez sur le liens suivant :';
$_MODULE['<{twenga}prestashop>twenga_58b6e05ecb12409685dec606271ca1ad'] = 'Liens sur le formulaire d\'inscription de Twenga';
$_MODULE['<{twenga}prestashop>twenga_fcb0c2a30548efc7048ea4bdfa4eba05'] = 'Annuler le tracking';
$_MODULE['<{twenga}prestashop>twenga_08473b95892d1cb8265ff2716cb81d54'] = 'Pour annuler le tracking, cliquez sur le lien suivant :';
$_MODULE['<{twenga}prestashop>twenga_bcfaccebf745acfd5e75351095a5394a'] = 'Annuler';
$_MODULE['<{twenga}prestashop>twenga_2938a03ab100963b7349d83257fa9333'] = 'Activer le tracking';
$_MODULE['<{twenga}prestashop>twenga_cd07439a0c70b97a595de73218094a36'] = 'Pour activer le tracking, cliquez sur le lien suivant :';
$_MODULE['<{twenga}prestashop>twenga_a13367a8e2a3f3bf4f3409079e3fdf87'] = 'Activer';

==> prestashop_1.4.0.9.zip: prestashop/modules/twenga/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{twenga}prestashop>twenga_400b0c914f01bcecf50b936e652695b2'] = 'l\'API de Twenga';
$_MODULE['<{twenga}prestashop>twenga_aa2bebad4fe3e659723e56cc7fcc6b1c'] = 'Exportez vos produits sur twenga.com et utilisez le tracker de Twenga pour les commandes de vos consommateurs.';
$_MODULE['<{twenga}prestashop>twenga_69e591b18e717d483dbaa8e3ce89ce59'] = 'Les paramètres ne sont pas autorisés (voir détails) :';
$_MODULE['<{twenga}prestashop>twenga_75a462904fadc0cc16d084efaef4a9d0'] = 'Une erreur s\'est produite avec une méthode de l\'API Twenga (voir détails) :';
$_MODULE['<{twenga}prestashop>twenga_cecc441ee7cb4cbbf1953d44018706de'] = 'Votre \"hashkey\" n\'est pas valide. Veuillez vérifier l\'email envoyé par Twenga.';
$_MODULE['<{twenga}prestashop>twenga_0483e8a340c21e92e606aa0cd2bafbe7'] = 'Votre nom d\'utilisateur n\'est pas valide. Veuillez vérifier l\'email envoyé par Twenga.';
$_MODULE['<{twenga}prestashop>twenga_54d92b2c87281ba0247f14a8eaea3278'] = 'Votre mot de passe n\'est pas valide. Veuillez vérifier l\'email envoyé par Twenga.';
$_MODULE['<{twenga}prestashop>twenga_b0d43a97cdf2e31e3d6b26640c2e71ee'] = 'Votre authentification à échoué.';
$_MODULE['<{twenga}prestashop>twenga_638a1f975b1d8361fcd459c532db6634'] = 'Veuillez vérifier l\'email envoyé par Twenga après souscription. Si une erreur persiste, contactez le service de Twenga.';
$_MODULE['<{twenga}prestashop>twenga_ddedf0f7b923553ef46616375e521381'] = 'Une erreur est apparue en passant les paramètres à l\'API Twenga.';
$_MODULE['<{twenga}prestashop>twenga_378f76d06c0d43d9fe5b5ab561e06d09'] = 'Pour utiliser le webservice de Twenga, vous devez activer l\'extension \'curl\' de PHP';
$_MODULE['<{twenga}prestashop>twenga_b0f7b5191764e268fe2d2a781314a0fd'] = 'Durant la récupération du lien de souscription par l\'API de Twenga certaines erreurs sont apparues :';
$_MODULE['<{twenga}prestashop>twenga_e7d6c412cbd6e430822d3b0dbad40498'] = 'Référencez vos produits sur Twenga : 500 clics offerts par Prestashop !';
$_MODULE['<{twenga}prestashop>twenga_f57bb21deb3c9ca234f74bb6435f271f'] = 'Comment tester Twenga et bénéficier des 500 premiers clics offerts :';
$_MODULE['<{twenga}prestashop>twenga_94bce708bfc56c62c6710db3c34db33d'] = 'Etape 1 : Cliquez sur ce lien spécial pour vous s’inscrire à \"Twenga Ready to Sell\"';
$_MODULE['<{twenga}prestashop>twenga_4f893ee24950069dd823e083338a456d'] = 's\'inscrire';
$_MODULE['<{twenga}prestashop>twenga_d4841389a7d896c92ecb8d81c0f42abf'] = '(des erreurs sont survenues : merci de contacter Twenga)';
$_MODULE['<{twenga}prestashop>twenga_2e7476b2a0122a4b8f8041e08b5e34bc'] = 'Etape 2 : Complétez le formulaire d’inscription Twenga.';
$_MODULE['<{twenga}prestashop>twenga_3526e9eda1bd86bf79472b6abf88ad98'] = 'Etape 3 : Une fois votre clé Twenga reçue, retournez ici et coller cette clé dans le champ « hash key » ainsi que votre login/pass Twenga Ready to Sell. Sauvegarder.';
$_MODULE['<{twenga}prestashop>twenga_bc88fe7063d7e7da0bf08003f21a1ad2'] = 'Augmentez votre traffic - 500 clics offerts';
$_MODULE['<{twenga}prestashop>twenga_d7c78c7a4356df39e7113405bd003ab5'] = 'Votre catalogue sera référencé sous une dizaine de jours. Une fois les 500 clics consommés, vous serez facturés au clic par catégorie de 0.05€ à 0.15€. Vous aurez accès à une interface de gestion complète. Vous pouvez partir à tout moment, moyennant 1 mois de préavis.';
$_MODULE['<{twenga}prestashop>twenga_f57624e0e72283c798dbd6cf90eed6ce'] = 'Authentification';
$_MODULE['<{twenga}prestashop>twenga_c7f7d1a930f6d4118e2a3938bc56d8dc'] = 'Après avoir rempli les étapes 1 et 2, renseignez ici la clé Twenga et votre login Twenga Ready to Sell';
$_MODULE['<{twenga}prestashop>twenga_a66daa775d445ee7da1bb20667b7c8e6'] = 'Flux Rss';
$_MODULE['<{twenga}prestashop>twenga_21baf392bfae2dadba6813e9fb843141'] = 'Hashkey';
$_MODULE['<{twenga}prestashop>twenga_99dea78007133396a7b8ed70578ac6ae'] = 'Login';
$_MODULE['<{twenga}prestashop>twenga_dc647eb65e6711e155375218212b3964'] = 'Mot de passe';
$_MODULE['<{twenga}prestashop>twenga_9915db4a30d338bd75b2880dcdc1a560'] = 'Votre catalogue sera référencé sous une dizaine de jours sur Twenga';
$_MODULE['<{twenga}prestashop>twenga_43781db5c40ecc39fd718685594f0956'] = 'Sauvegarder';
$_MODULE['<{twenga}prestashop>twenga_f7fba53a11823899183e6634a599f66e'] = 'Informations qui pré-rempliront le formulaire d\'inscription Twenga';
$_MODULE['<{twenga}prestashop>twenga_ce3991031fe3a5153f6d4cae2cbf6a94'] = 'Les informations suivantes seront pré remplies dans lors de votre inscription à Twenga Ready to Sell. Merci de vérifier si les informations sont correctes.';
$_MODULE['<{twenga}prestashop>twenga_87fa3060dcb794dee724d4cb59b13cd6'] = 'l\'url du site';
$_MODULE['<{twenga}prestashop>twenga_1ce44171ccfff23c4fc2c836ad6543f4'] = 'Flux Rss, la liste des produits en xml.';
$_MODULE['<{twenga}prestashop>twenga_670e0c29cdde1886890aebc751cd6e89'] = 'Valeur automatiquement remplie, ne la changer pas.';
$_MODULE['<{twenga}prestashop>twenga_59716c97497eb9694541f7c3d37b1a4d'] = 'Pays';
$_MODULE['<{twenga}prestashop>twenga_95f01a5bae7b4b64a76372538e4fd315'] = 'Le pays de la société E-commerce. Utilisez le code ISO_3166-1 Alpha-2 pour le format de pays ';
$_MODULE['<{twenga}prestashop>twenga_734b599bad38d4210614bc176c53fefe'] = 'Nom du site';
$_MODULE['<{twenga}prestashop>twenga_dff4bf10409100d989495c6d5486035e'] = 'Nom de famille';
$_MODULE['<{twenga}prestashop>twenga_04176f095283bc729f1e3926967e7034'] = 'Prénom';
$_MODULE['<{twenga}prestashop>twenga_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'E-mail';
$_MODULE['<{twenga}prestashop>twenga_bcc254b55c4a1babdf1dcb82c207506b'] = 'Téléphone';
$_MODULE['<{twenga}prestashop>twenga_28bea34e08fa23a7d394c93bad717733'] = 'Nom de l\'organisation';
$_MODULE['<{twenga}prestashop>twenga_4ff5049a0938728934387c4d9cf38f94'] = 'Infos juridiques';
$_MODULE['<{twenga}prestashop>twenga_dfd7564600980a3470f2ec24766653fe'] = 'Infos juridiques de la société.';
$_MODULE['<{twenga}prestashop>twenga_dd7bf230fde8d4836917806aff6a6b27'] = 'Adresse';
$_MODULE['<{twenga}prestashop>twenga_572ed696f21038e6cc6c86bb272a3222'] = 'Code postale';
$_MODULE['<{twenga}prestashop>twenga_57d056ed0984166336b7879c2af3657f'] = 'Ville';
$_MODULE['<{twenga}prestashop>twenga_c9cc8cce247e49bae79f15173ce97354'] = 'Sauvegarder';
$_MODULE['<{twenga}prestashop>twenga_fcb0c2a30548efc7048ea4bdfa4eba05'] = 'Annuler le tracking';
$_MODULE['<{twenga}prestashop>twenga_08473b95892d1cb8265ff2716cb81d54'] = 'Pour annuler le tracking, cliquez sur le lien suivant :';
$_MODULE['<{twenga}prestashop>twenga_bcfaccebf745acfd5e75351095a5394a'] = 'Annuler';
$_MODULE['<{twenga}prestashop>twenga_2938a03ab100963b7349d83257fa9333'] = 'Activer le tracking';
$_MODULE['<{twenga}prestashop>twenga_cd07439a0c70b97a595de73218094a36'] = 'Pour activer le tracking, cliquez sur le lien suivant :';
$_MODULE['<{twenga}prestashop>twenga_a13367a8e2a3f3bf4f3409079e3fdf87'] = 'Activer';
$_MODULE['<{twenga}prestashop>TwengaObj_2823b98d043387f608f16d5830d63f5f'] = 'Pour activer le module Twenga, la constante \"PARTNER_AUTH_KEY\" doit être définit. L\'installation par défault de Prestashop contient cette valeur.';
$_MODULE['<{twenga}prestashop>TwengaObj_9f7cd403f4ab77ce8c00426d4a01345e'] = 'L\'object pour valider les champs doit être une instance de la classe TwengaFields';
$_MODULE['<{twenga}prestashop>TwengaObj_b78d4ca3fa82bab9e21c8110511ed947'] = 'Le retour XML de la réponse HTTP n\'est pas analysable :';
$_MODULE['<{twenga}prestashop>TwengaObj_7edc522b57a063ef075b68fdb791af40'] = 'la réponse HTTP est vide';
$_MODULE['<{twenga}prestashop>TwengaObj_d00d3f61833c8686be3f0ca7df670e20'] = 'Cet appel aux Services Web Twenga à échoué et à retourné un statut HTTP de %d. Ce qui veut dire :';
$_MODULE['<{twenga}prestashop>TwengaObj_5177c3a8e526ccb227441827d43d9583'] = 'La fonction que vous appelez n\'existe pas';
$_MODULE['<{twenga}prestashop>TwengaObj_3718cdfdc7439f35aed9f053b5991baf'] = 'Un champ requis est vide.';
$_MODULE['<{twenga}prestashop>TwengaObj_f97fd38d65fe891d07fc1a157b0752a2'] = 'Le type du paramètre qui est envoyé est différent du type attendu.';
$_MODULE['<{twenga}prestashop>TwengaObj_737b702af5cbf3c4b0e7404592bae85e'] = 'Le hash key n\'est pas valide';
$_MODULE['<{twenga}prestashop>TwengaObj_c54550e963195bd4e80b862f40b8d574'] = 'Le hash key est requis';
$_MODULE['<{twenga}prestashop>TwengaObj_c4e170c475b0285f284ccb066bcd81f4'] = 'Aucune commandes trouvées. Regardez les parmètres que vous transmettez';
$_MODULE['<{twenga}prestashop>TwengaObj_54441256ce04ab07a29463646d0a9931'] = 'Une authentification est requise.';
$_MODULE['<{twenga}prestashop>TwengaObj_802b207b05fe5cea22e11b9db804b33d'] = 'L\'authentification a échoué.';
$_MODULE['<{twenga}prestashop>TwengaObj_629a8cfa226f98886062bfdc9666e266'] = 'L\'url n\'est pas valide.';
$_MODULE['<{twenga}prestashop>TwengaObj_9fb66ea632c1aff220b180918df3c77c'] = 'Le serveur à rencontrer une \"internal server error\".';
$_MODULE['<{twenga}prestashop>TwengaObj_6e182f2ba494a6720ce552ed2a255403'] = 'Le serveur n\'est pas accessible pour le moment';
$_MODULE['<{twenga}prestashop>TwengaObj_4252fb7eb531ed1ec250e5c16f8ced37'] = 'Cet appel aux Services Web Twenga a retourné un statut HTTP inattendu :';
$_MODULE['<{twenga}prestashop>TwengaObj_5619f08f21127bd8f72ec9bbb25031ac'] = 'Erreur n°';
